OC.L10N.register(
    "core",
    {
    "Please select a file." : "Seleccioneu un fitxer.",
    "File is too big" : "El fitxer és massa gran",
    "The selected file is not an image." : "El fitxer seleccionat no és una imatge.",
    "The selected file cannot be read." : "No s'ha pogut llegir el fitxer seleccionat.",
    "The file was uploaded" : "S'ha pujat el fitxer",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El fitxer pujat supera la directiva upload_max_filesize del fitxer php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El fitxer pujat supera la directiva MAX_FILE_SIZE que s'ha especificat en el formulari HTML",
    "The file was only partially uploaded" : "El fitxer només s'ha pujat parcialment",
    "No file was uploaded" : "No s'ha pujat cap fitxer",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No s'ha pogut escriure el fitxer en el disc",
    "A PHP extension stopped the file upload" : "Una extensió del PHP ha aturat la pujada del fitxer",
    "Invalid file provided" : "El fitxer proporcionat no és vàlid",
    "No image or file provided" : "No s'ha proporcionat cap imatge o fitxer",
    "Unknown filetype" : "Tipus de fitxer desconegut",
    "An error occurred. Please contact your admin." : "S'ha produït un error. Contacteu amb l'administrador.",
    "Invalid image" : "La imatge no és vàlida",
    "No temporary profile picture available, try again" : "No hi ha cap imatge temporal de perfil disponible; torneu-ho a provar",
    "No crop data provided" : "No s'han proporcionat dades de retall",
    "No valid crop data provided" : "Les dades de retall proporcionades no són vàlides",
    "Crop is not square" : "El retall no és quadrat",
    "State token does not match" : "El testimoni d'estat no coincideix",
    "Invalid app password" : "La contrasenya de l'aplicació no és vàlida",
    "Could not complete login" : "No s'ha pogut completar l'inici de sessió",
    "State token missing" : "Falta el testimoni d'estat",
    "Your login token is invalid or has expired" : "El testimoni d'inici de sessió no és vàlid o ha caducat",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Aquesta versió de la comunitat del Nextcloud no té suport i les notificacions automàtiques estan limitades.",
    "Login" : "Inici de sessió",
    "Unsupported email length (>255)" : "Longitud de correu electrònic no admesa (>255)",
    "Password reset is disabled" : "La reinicialització de contrasenya està inhabilitada",
    "Could not reset password because the token is expired" : "No s'ha pogut reinicialitzar la contrasenya perquè el testimoni ha caducat",
    "Could not reset password because the token is invalid" : "No s'ha pogut reinicialitzar la contrasenya perquè el testimoni no és vàlid",
    "Password is too long. Maximum allowed length is 469 characters." : "La contrasenya és massa llarga. La longitud màxima permesa és de 469 caràcters.",
    "%s password reset" : "Reinicialització de la contrasenya del %s",
    "Password reset" : "Reinicialització de la contrasenya",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Feu clic en el botó següent per a reinicialitzar la contrasenya. Si no heu sol·licitat un canvi de contrasenya, ignoreu aquest correu electrònic.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Feu clic en l'enllaç següent per a reinicialitzar la contrasenya. Si no heu sol·licitat un canvi de contrasenya, ignoreu aquest correu electrònic.",
    "Reset your password" : "Reinicialitza la contrasenya",
    "The given provider is not available" : "El proveïdor indicat no està disponible",
    "Task not found" : "No s'ha trobat la tasca",
    "Internal error" : "Error intern",
    "Not found" : "No s'ha trobat",
    "Bad request" : "Sol·licitud incorrecta",
    "Requested task type does not exist" : "El tipus de tasca sol·licitat no existeix",
    "Necessary language model provider is not available" : "El proveïdor de models de llengua necessari no està disponible",
    "No text to image provider is available" : "No hi ha cap proveïdor de text a imatge disponible",
    "Image not found" : "Imatge no trobada",
    "No translation provider available" : "No hi ha cap proveïdor de traduccions disponible",
    "Could not detect language" : "No s'ha pogut detectar la llengua",
    "Unable to translate" : "No s'ha pogut traduir",
    "[%d / %d]: %s" : "[%d/%d]: %s",
    "Repair step:" : "Pas de reparació:",
    "Repair info:" : "Informació de reparació:",
    "Repair warning:" : "Avís de reparació:",
    "Repair error:" : "Error de reparació:",
    "Nextcloud Server" : "Servidor del Nextcloud",
    "Some of your link shares have been removed" : "S'han suprimit alguns dels vostres enllaços compartits",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "A causa d'un error de seguretat, hem suprimit alguns dels vostres enllaços compartits. Consulteu l'enllaç per a obtenir més informació.",
    "The account limit of this instance is reached." : "S'ha arribat al límit de compte d'aquesta instància.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Introduïu la vostra clau de subscripció a l'aplicació de suport per augmentar el límit del compte. Això també us atorga tots els avantatges addicionals que ofereix Nextcloud Enterprise i és molt recomanable per al funcionament en empreses.",
    "Learn more ↗" : "Més informació ↗",
    "Preparing update" : "S'està preparant l'actualització",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Utilitzeu l'actualitzador de línia d'ordres; l'actualització mitjançant el navegador està inhabilitada en el fitxer config.php.",
    "Turned on maintenance mode" : "S'ha activat el mode de manteniment",
    "Turned off maintenance mode" : "S'ha desactivat el mode de manteniment",
    "Maintenance mode is kept active" : "El mode de manteniment es manté activat",
    "Updating database schema" : "S'està actualitzant l'esquema de la base de dades",
    "Updated database" : "S'ha actualitzat la base de dades",
    "Update app \"%s\" from App Store" : "S'ha actualitzat l'aplicació «%s» des de la botiga d'aplicacions",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "S'està comprovant si es pot actualitzar l'esquema de la base de dades de %s (pot tardar molta estona segons la mida de la base de dades)",
    "Updated \"%1$s\" to %2$s" : "S'ha actualitzat «%1$s» a la versió %2$s",
    "Set log level to debug" : "S'ha establert el nivell de registre en depuració",
    "Reset log level" : "S'ha reinicialitzat el nivell de registre",
    "Starting code integrity check" : "S'està iniciant la comprovació d'integritat del codi",
    "Finished code integrity check" : "La comprovació d'integritat del codi ha finalitzat",
    "%s (incompatible)" : "%s (no compatible)",
    "The following apps have been disabled: %s" : "S'han inhabilitat les aplicacions següents: %s",
    "Already up to date" : "Ja teniu la versió més recent",
    "Unknown" : "Desconegut",
    "PNG image" : "Imatge PNG",
    "unknown text" : "text desconegut",
    "Hello world!" : "Hola a tothom!",
    "sunny" : "assolellat",
    "Hello {name}, the weather is {weather}" : "Hola, {name}, el temps és {weather}",
    "Hello {name}" : "Hola, {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Aquests són els resultats de la cerca<script>alert(1)</script></strong>",
    "new" : "nou",
    "_download %n file_::_download %n files_" : ["baixa %n fitxer","baixa %n fitxers"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "L'actualització està en curs; si sortiu d'aquesta pàgina, és possible que s'interrompi el procés en alguns entorns.",
    "Update to {version}" : "Actualització a la versió {version}",
    "An error occurred." : "S'ha produït un error.",
    "Please reload the page." : "Torneu a carregar la pàgina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "S'ha produït un error durant l'actualització. Per a obtenir més informació, <a href=\"{url}\">consulteu la nostra publicació en el fòrum</a> que parla d'aquest error.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "S'ha produït un error durant l'actualització. Informeu d'aquest error a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunitat del Nextcloud</a>.",
    "Continue to {productName}" : "Continua al {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["L'actualització ha finalitzat correctament. Se us redirigirà al {productName} d'aquí a %n segon.","L'actualització ha finalitzat correctament. Se us redirigirà al {productName} d'aquí a %n segons."],
    "Applications menu" : "Menú d'aplicacions",
    "Apps" : "Aplicacions",
    "More apps" : "Més aplicacions",
    "_{count} notification_::_{count} notifications_" : ["{count} notificació","{count} notificacions"],
    "No" : "No",
    "Yes" : "Sí",
    "The remote URL must include the user." : "L'URL remot ha d'incloure l'usuari.",
    "Invalid remote URL." : "URL remot no vàlid.",
    "Failed to add the public link to your Nextcloud" : "No s'ha pogut afegir l'enllaç públic al vostre Nextcloud",
    "Federated user" : "Usuari federat",
    "user@your-nextcloud.org" : "usuari@el-teu-nextcloud.org",
    "Create share" : "Crea l'element compartit",
    "Please copy the link manually:" : "Copieu l'enllaç manualment:",
    "Custom date range" : "Interval de dates personalitzat",
    "Pick start date" : "Trieu la data d'inici",
    "Pick end date" : "Trieu la data de finalització",
    "Search in date range" : "Cerca a l'interval de dates",
    "Search in current app" : "Cerca a l'aplicació actual",
    "Clear search" : "Neteja la cerca",
    "Search everywhere" : "Cerca a tot arreu",
    "Searching …" : "S'està cercant…",
    "Start typing to search" : "Escriviu per a cercar",
    "No matching results" : "No hi ha resultats coincidents",
    "Today" : "Avui",
    "Last 7 days" : "Últims 7 dies",
    "Last 30 days" : "Últims 30 dies",
    "This year" : "Aquest any",
    "Last year" : "Últim any",
    "Unified search" : "Cerca unificada",
    "Search apps, files, tags, messages" : "Cerca aplicacions, fitxers, etiquetes, missatges",
    "Places" : "Llocs",
    "Date" : "Data",
    "Search people" : "Cerca gent",
    "People" : "Persones",
    "Filter in current view" : "Filtra a la vista actual",
    "Results" : "Resultats",
    "Load more results" : "Carrega més resultats",
    "Search in" : "Cerca en",
    "Log in" : "Inicia la sessió",
    "Logging in …" : "S'està iniciant la sessió…",
    "Log in to {productName}" : "Inici de sessió del {productName}",
    "Wrong login or password." : "Inici de sessió o contrasenya incorrectes.",
    "This account is disabled" : "Aquest compte està inhabilitat",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hem detectat diversos intents d'inici de sessió no vàlids des de la vostra IP. Per tant, el següent inici de sessió s'ha endarrerit fins a 30 segons.",
    "Account name or email" : "Nom del compte o adreça electrònica",
    "Account name" : "Nom de compte",
    "Server side authentication failed!" : "S'ha produït un error en l'autenticació del servidor!",
    "Please contact your administrator." : "Contacteu amb l'administrador.",
    "An internal error occurred." : "S'ha produït un error intern.",
    "Please try again or contact your administrator." : "Torneu-ho a provar o contacteu amb l'administrador.",
    "Password" : "Contrasenya",
    "Log in with a device" : "Inicia la sessió amb un dispositiu",
    "Login or email" : "Inicieu sessió o correu electrònic",
    "Your account is not setup for passwordless login." : "El vostre compte no està configurat per a l'inici de sessió sense contrasenya.",
    "Your connection is not secure" : "La vostra connexió no és segura",
    "Passwordless authentication is only available over a secure connection." : "L'autenticació sense contrasenya només està disponible amb una connexió segura.",
    "Browser not supported" : "El navegador no és compatible",
    "Passwordless authentication is not supported in your browser." : "L'autenticació sense contrasenya no és compatible amb el vostre navegador.",
    "Reset password" : "Reinicialitza la contrasenya",
    "Back to login" : "Torna a l'inici de sessió",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Si aquest compte existeix, s'ha enviat un missatge de restabliment de la contrasenya a la seva adreça de correu electrònic. Si no el rebeu, verifiqueu la vostra adreça de correu electrònic i/o inici de sessió, comproveu les vostres carpetes de correu brossa o demaneu ajuda a l'administració local.",
    "Couldn't send reset email. Please contact your administrator." : "No s'ha pogut reinicialitzar l'adreça electrònica. Contacteu amb l'administrador.",
    "Password cannot be changed. Please contact your administrator." : "No es pot canviar la contrasenya. Contacteu amb l'administrador.",
    "New password" : "Contrasenya nova",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Els vostres fitxers estan xifrats. No hi haurà manera de recuperar les dades quan reinicialitzeu la contrasenya. Si no sabeu el que feu, contacteu amb l'administrador abans de continuar. Segur que voleu continuar ara?",
    "I know what I'm doing" : "Sé el que faig",
    "Resetting password" : "S'està reinicialitzant la contrasenya",
    "Schedule work & meetings, synced with all your devices." : "Planifiqueu feina i reunions, amb sincronització entre tots els vostres dispositius.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Deseu la informació de companys i amistats en un sol lloc sense revelar-ne la informació privada.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicació senzilla de correu electrònic ben integrada amb les aplicacions Fitxers, Contactes i Calendari.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Xat, videotrucades, ús compartit de pantalla, reunions en línia i conferències web – fal navegador i amb aplicacions mòbils.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documents, fulls de càlcul i presentacions col·laboratius, basats en Collabora Online.",
    "Distraction free note taking app." : "Aplicació per a prendre notes sense distraccions.",
    "Recommended apps" : "Aplicacions recomanades",
    "Loading apps …" : "S'estan carregant les aplicacions…",
    "Could not fetch list of apps from the App Store." : "No s'ha pogut obtenir la llista d'aplicacions de la botiga d'aplicacions.",
    "App download or installation failed" : "No s'ha pogut baixar o instal·lar l'aplicació",
    "Cannot install this app because it is not compatible" : "No s'ha pogut instal·lar aquesta aplicació, perquè no és compatible",
    "Cannot install this app" : "No es pot instal·lar aquesta aplicació",
    "Skip" : "Omet",
    "Installing apps …" : "S'estan instal·lant les aplicacions…",
    "Install recommended apps" : "Instal·la les aplicacions recomanades",
    "Avatar of {displayName}" : "Avatar de {displayName}",
    "Settings menu" : "Menú de paràmetres",
    "Loading your contacts …" : "S'estan carregant els contactes…",
    "Looking for {term} …" : "S'està cercant {term}…",
    "Search contacts" : "Cerca de contactes",
    "Reset search" : "Reinicialitza la cerca",
    "Search contacts …" : "Cerqueu contactes…",
    "Could not load your contacts" : "No s'han pogut carregar els contactes",
    "No contacts found" : "No s'ha trobat cap contacte",
    "Show all contacts" : "Mostra tots els contactes",
    "Install the Contacts app" : "Instal·la l'aplicació Contactes",
    "Search" : "Cerca",
    "No results for {query}" : "No hi ha cap resultat per a {query}",
    "Press Enter to start searching" : "Premeu Retorn per a iniciar la cerca",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Introduïu {minSearchLength} caràcter o més per a cercar","Introduïu {minSearchLength} caràcters o més per a cercar"],
    "An error occurred while searching for {type}" : "S'ha produït un error mentre en cercar {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "La cerca comença quan escriviu i podeu accedir als resultats amb les tecles de cursor",
    "Search for {name} only" : "Cerca només de {name}",
    "Loading more results …" : "S'estan carregant més resultats…",
    "Forgot password?" : "Heu oblidat la contrasenya?",
    "Back to login form" : "Torna al formulari d'inici de sessió",
    "Back" : "Torna",
    "Login form is disabled." : "El formulari d'inici de sessió està inhabilitat.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulari d'inici de sessió de Nextcloud està desactivat. Utilitzeu una altra opció d'inici de sessió si està disponible o poseu-vos en contacte amb la vostra administració.",
    "More actions" : "Més accions",
    "Password is too weak" : "La contrasenya és massa feble",
    "Password is weak" : "La contrasenya és feble",
    "Password is average" : "La contrasenya és mitjana",
    "Password is strong" : "La contrasenya és segura",
    "Password is very strong" : "La contrasenya és molt forta",
    "Password is extremely strong" : "La contrasenya és extremadament segura",
    "Unknown password strength" : "Força de contrasenya desconeguda",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Probablement es pugui accedir al vostre directori de dades i fitxers des d'Internet perquè el fitxer <code>.htaccess</code> no funciona.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Per obtenir informació sobre com configurar correctament el vostre servidor, {linkStart}consulteu la documentació{linkEnd}",
    "Autoconfig file detected" : "S'ha detectat un fitxer de configuració automàtica",
    "The setup form below is pre-filled with the values from the config file." : "El formulari de configuració següent està emplenat prèviament amb els valors del fitxer de configuració.",
    "Security warning" : "Avís de seguretat",
    "Create administration account" : "Crear un compte d'administració",
    "Administration account name" : "Nom del compte d'administració",
    "Administration account password" : "Contrasenya del compte d'administració",
    "Storage & database" : "Emmagatzematge i base de dades",
    "Data folder" : "Carpeta de dades",
    "Database configuration" : "Configuració de la base de dades",
    "Only {firstAndOnlyDatabase} is available." : "Només {firstAndOnlyDatabase} està disponible.",
    "Install and activate additional PHP modules to choose other database types." : "Instal·leu i activeu mòduls del PHP addicionals per a seleccionar altres tipus de bases de dades.",
    "For more details check out the documentation." : "Per a conèixer més detalls, consulteu la documentació.",
    "Performance warning" : "Avís de rendiment",
    "You chose SQLite as database." : "Heu triat l'SQLite com a base de dades.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "L'SQLite només s'hauria d'utilitzar per a instàncies mínimes i de desenvolupament. Per a sistemes en producció, us recomanem un rerefons de base de dades diferent.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si utilitzeu clients per a la sincronització de fitxers, no es recomana en absolut l'ús de l'SQLite.",
    "Database user" : "Usuari de la base de dades",
    "Database password" : "Contrasenya de la base de dades",
    "Database name" : "Nom de la base de dades",
    "Database tablespace" : "Espai de taula de la base de dades",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifiqueu el número de port, juntament amb el nom del servidor (per exemple, localhost:5432).",
    "Database host" : "Servidor de la base de dades",
    "localhost" : "localhost",
    "Installing …" : "S'està instal·lant…",
    "Install" : "Instal·la",
    "Need help?" : "Necessiteu ajuda?",
    "See the documentation" : "Consulteu la documentació",
    "{name} version {version} and above" : "{name} versió {version} i posterior",
    "This browser is not supported" : "Aquest navegador no és compatible",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "El vostre navegador no és compatible. Actualitzeu a una versió més recent o compatible.",
    "Continue with this unsupported browser" : "Continua amb aquest navegador no compatible",
    "Supported versions" : "Versions compatibles",
    "Search {types} …" : "Cerqueu {types}…",
    "Choose {file}" : "Tria {file}",
    "Choose" : "Tria",
    "Copy to {target}" : "Copia a {target}",
    "Copy" : "Copia",
    "Move to {target}" : "Mou a {target}",
    "Move" : "Mou",
    "OK" : "D'acord",
    "read-only" : "només de lectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicte de fitxers","{count} conflictes de fitxers"],
    "One file conflict" : "Un conflicte de fitxers",
    "New Files" : "Fitxers nous",
    "Already existing files" : "Fitxers que ja existeixen",
    "Which files do you want to keep?" : "Quins fitxers voleu conservar?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleccioneu les dues versions, s'afegirà un número al nom del fitxer copiat.",
    "Cancel" : "Cancel·la",
    "Continue" : "Continua",
    "(all selected)" : "(selecció: tot)",
    "({count} selected)" : "(selecció: {count})",
    "Error loading file exists template" : "S'ha produït un error en carregar la plantilla de fitxer existent",
    "Saving …" : "S'està desant…",
    "seconds ago" : "fa uns segons",
    "Connection to server lost" : "S'ha perdut la connexió amb el servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Hi ha hagut un problema en carregar la pàgina, es tornarà a carregar d'aquí a %n segon","Hi ha hagut un problema en carregar la pàgina, es tornarà a carregar d'aquí a %n segons"],
    "Add to a project" : "Afegeix a un projecte",
    "Show details" : "Mostra els detalls",
    "Hide details" : "Amaga els detalls",
    "Rename project" : "Canvia el nom del projecte",
    "Failed to rename the project" : "No s'ha pogut canviar el nom del projecte",
    "Failed to create a project" : "No s'ha pogut crear el projecte",
    "Failed to add the item to the project" : "No s'ha pogut afegir l'element al projecte",
    "Connect items to a project to make them easier to find" : "Connecteu elements a un projecte per a trobar-los més fàcilment",
    "Type to search for existing projects" : "Escriviu per a cercar projectes existents",
    "New in" : "Nou a",
    "View changelog" : "Mostra el registre de canvis",
    "No action available" : "No hi ha cap acció disponible",
    "Error fetching contact actions" : "S'ha produït un error en carregar les accions del contacte",
    "Close \"{dialogTitle}\" dialog" : "Tanca el quadre de diàleg «{dialogTitle}»",
    "Email length is at max (255)" : "La longitud del correu electrònic és màxima (255)",
    "Non-existing tag #{tag}" : "L'etiqueta #{tag} no existeix",
    "Restricted" : "Restringit",
    "Invisible" : "Invisible",
    "Delete" : "Suprimeix",
    "Rename" : "Canvia el nom",
    "Collaborative tags" : "Etiquetes col·laboratives",
    "No tags found" : "No s'ha trobat cap etiqueta",
    "Clipboard not available, please copy manually" : "El porta-retalls no està disponible; copieu-lo manualment",
    "Personal" : "Personal",
    "Accounts" : "Comptes",
    "Admin" : "Administració",
    "Help" : "Ajuda",
    "Access forbidden" : "Accés prohibit",
    "Back to %s" : "Torna a %s",
    "Page not found" : "No s'ha trobat la pàgina",
    "The page could not be found on the server or you may not be allowed to view it." : "No s'ha trobat la pàgina en el servidor o és possible que no tingueu permís per a visualitzar-la.",
    "Too many requests" : "Excés de sol·licituds",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "La vostra xarxa ha enviat un excés de sol·licituds. Torneu-ho a provar més tard o contacte amb l'administrador si és un error.",
    "Error" : "Error",
    "Internal Server Error" : "Error intern del servidor",
    "The server was unable to complete your request." : "El servidor no ha pogut completar la teva sol·licitud.",
    "If this happens again, please send the technical details below to the server administrator." : "Si això torna a passar, si us plau, envieu els detalls tècnics següents a l'administrador del servidor.",
    "More details can be found in the server log." : "Podeu trobar més detalls en el registre del servidor.",
    "For more details see the documentation ↗." : "Per a més detalls consulteu la documentació ↗.",
    "Technical details" : "Detalls tècnics",
    "Remote Address: %s" : "Adreça remota: %s",
    "Request ID: %s" : "ID de la sol·licitud: %s",
    "Type: %s" : "Tipus: %s",
    "Code: %s" : "Codi: %s",
    "Message: %s" : "Missatge: %s",
    "File: %s" : "Fitxer: %s",
    "Line: %s" : "Línia: %s",
    "Trace" : "Traça",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sembla que intenteu reinstal·lar el Nextcloud, però falta el fitxer CAN_INSTALL en la carpeta de configuració. Creeu el fitxer CAN_INSTALL en la carpeta de configuració per a continuar.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "No s'ha pogut suprimir CAN_INSTALL de la carpeta de configuració. Suprimiu-lo manualment.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aquesta aplicació requereix el JavaScript per a funcionar correctament. {linkstart}Habiliteu el JavaScript{linkend} i torneu a carregar la pàgina.",
    "Skip to main content" : "Salta al contingut principal",
    "Skip to navigation of app" : "Salta a la navegació de l'aplicació",
    "Go to %s" : "Ves a %s",
    "Get your own free account" : "Obteniu el vostre propi compte gratuït",
    "Connect to your account" : "Connexió al vostre compte",
    "Please log in before granting %1$s access to your %2$s account." : "Inicieu la sessió abans de concedir a %1$s accés al vostre compte del %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si no intenteu configurar un dispositiu o una aplicació nova, algú intenta enganyar-vos perquè li concediu accés a les vostres dades. En aquest cas, no procediu i contacteu amb l'administrador del sistema.",
    "App password" : "Contrasenya de l'aplicació",
    "Grant access" : "Concedeix l'accés",
    "Alternative log in using app password" : "Inicieu sessió alternativa amb la contrasenya de l'aplicació",
    "Account access" : "Accés al compte",
    "Currently logged in as %1$s (%2$s)." : "S'ha iniciat la sessió com a %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Esteu a punt de concedir a %1$s accés al vostre compte del %2$s.",
    "Account connected" : "S'ha connectat el compte",
    "Your client should now be connected!" : "El client ara hauria d'estar connectat!",
    "You can close this window." : "Podeu tancar aquesta finestra.",
    "Previous" : "Anterior",
    "This share is password-protected" : "Aquest element compartit està protegit amb contrasenya",
    "The password is wrong or expired. Please try again or request a new one." : "La contrasenya és incorrecta o ha vençut. Torneu-ho a provar o sol·liciteu-ne una de nova.",
    "Please type in your email address to request a temporary password" : "Introduïu la vostra adreça electrònica per a sol·licitar una contrasenya temporal",
    "Email address" : "Adreça electrònica",
    "Password sent!" : "S'ha enviat la contrasenya!",
    "You are not authorized to request a password for this share" : "No teniu autorització per a sol·licitar una contrasenya d'aquest element compartit",
    "Two-factor authentication" : "Autenticació de doble factor",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La seguretat millorada està habilitada per al vostre compte. Trieu un segon factor d'autenticació:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "No s'ha pogut carregar almenys un dels mètodes d'autenticació de doble factor permesos. Contacteu amb l'administrador.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "L'autenticació de doble factor és obligatòria, però no l'heu configurat en el vostre compte. Contacteu amb l'administrador perquè us ajudi.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "L'autenticació de doble factor és obligatòria, però no l'heu configurat en el vostre compte. Continueu per a configurar l'autenticació de doble factor.",
    "Set up two-factor authentication" : "Configura l'autenticació de doble factor",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "L'autenticació de doble factor és obligatòria, però no l'heu configurat en el vostre compte. Utilitzeu un dels codis de reserva per a iniciar la sessió o contacteu amb l'administrador perquè us ajudi.",
    "Use backup code" : "Utilitza un codi de reserva",
    "Cancel login" : "Cancel·la l'inici de sessió",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "La seguretat millorada és obligatòria per al vostre compte. Trieu quin proveïdor voleu configurar:",
    "Error while validating your second factor" : "S'ha produït un error en validar el segon factor",
    "Access through untrusted domain" : "Accés a través d'un domini que no és de confiança",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Contacteu amb l'administrador. Si sou l'administrador, editeu el paràmetre «trusted_domains» del fitxer config/config.php tal com es mostra en el fitxer config.sample.php d'exemple.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Podeu trobar més informació sobre com configurar-ho en la %1$sdocumentació%2$s.",
    "App update required" : "Cal actualitzar l'aplicació",
    "%1$s will be updated to version %2$s" : "%1$s s'actualitzarà a la versió %2$s",
    "The following apps will be updated:" : "S'actualitzaran les aplicacions següents:",
    "These incompatible apps will be disabled:" : "S'inhabilitaran aquestes aplicacions no compatibles:",
    "The theme %s has been disabled." : "S'ha inhabilitat el tema %s.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Assegureu-vos que hàgiu fet una còpia de seguretat de la base de dades, del fitxer de configuració i de la carpeta de dades abans de continuar.",
    "Start update" : "Inicia l'actualització",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitar que s'exhaureixi el temps d'espera en instal·lacions grans, podeu executar l'ordre següent en la carpeta d'instal·lació:",
    "Detailed logs" : "Registres detallats",
    "Update needed" : "Cal actualitzar",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Utilitzeu l'actualitzador de línia d'ordres perquè teniu una instància gran amb més de 50 comptes.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Per a obtenir ajuda, consulteu la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\"> documentació</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sé que si procedeixo amb l'actualització mitjançant la interfície d'usuari web hi ha el risc que la sol·licitud exhaureixi el temps d'espera i que podria causar una pèrdua de dades, però tinc una còpia de seguretat i sé com restaurar la meva instància en cas d'error.",
    "Upgrade via web on my own risk" : "Actualitza des del web sota la meva responsabilitat",
    "Maintenance mode" : "Mode de manteniment",
    "This %s instance is currently in maintenance mode, which may take a while." : "Aquesta instància del %s està actualment en mode de manteniment i podria estar-ho una estona.",
    "This page will refresh itself when the instance is available again." : "Aquesta pàgina s'actualitzarà automàticament quan la instància torni a estar disponible.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacteu amb l'administrador del sistema si aquest missatge persisteix o si apareix inesperadament.",
    "Error occurred while checking server setup" : "S'ha produït un error en comprovar la configuració del servidor",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Per a conèixer més detalls, consulteu la {linkstart}documentació ↗{linkend}.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Xat, videotrucades, pantalla compartida, reunions en línia i conferències per Internet; en el navegador i amb aplicacions mòbils.",
    "You have not added any info yet" : "Encara no heu afegit cap informació",
    "{user} has not added any info yet" : "{user} encara no ha afegit cap informació",
    "Error opening the user status modal, try hard refreshing the page" : "S'ha produït un error en obrir el quadre de diàleg modal d'estat de l'usuari, proveu d'actualitzar la pàgina",
    "Edit Profile" : "Edita el perfil",
    "The headline and about sections will show up here" : "La capçalera i les seccions d'informació es mostraran aquí",
    "Very weak password" : "Contrasenya molt feble",
    "Weak password" : "Contrasenya feble",
    "So-so password" : "Contrasenya justa",
    "Good password" : "Contrasenya bona",
    "Strong password" : "Contrasenya forta",
    "Profile not found" : "No s'ha trobat el perfil",
    "The profile does not exist." : "El perfil no existeix.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La carpeta de dades i els fitxers probablement són accessibles des d'Internet perquè el fitxer .htaccess no funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per a obtenir informació sobre com configurar correctament el servidor, consulteu la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentació</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Creació d'un compte d'administrador</strong>",
    "New admin account name" : "Nou nom del compte d'administració",
    "New admin password" : "Nova contrassenya d'administració",
    "Show password" : "Mostra la contrasenya",
    "Toggle password visibility" : "Canvia la visibilitat de la contrasenya",
    "Configure the database" : "Configuració de la base de dades",
    "Only %s is available." : "Només hi ha disponible %s.",
    "Database account" : "Compte de base de dades",
    "Direct link copied to clipboard" : "Enllaç directe copiat al porta-retalls"
},
"nplurals=2; plural=(n != 1);");
